@@ -19,6 +19,8 @@ import numba
 
 from pprint import pprint
 from astropy import units as u
+from astropy.constants import c
+
 from datetime import datetime, timedelta
 
 #https://gwosc.readthedocs.io/en/stable/
@@ -352,8 +354,8 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
     speed_array = speed_vector_parallel(t1,t2,f_sampling)
 
     #compute cartesian coordinate from RA DEC.
-    c = SkyCoord(ra= src_pos[0]*u.degree, dec=src_pos[1]*u.degree, frame='icrs')
-    src_pos = [c.cartesian.x.value, c.cartesian.y.value, c.cartesian.z.value]
+    co = SkyCoord(ra= src_pos[0]*u.degree, dec=src_pos[1]*u.degree, frame='icrs')
+    src_pos = [co.cartesian.x.value, co.cartesian.y.value, co.cartesian.z.value]
 
     #compute the scalar product
     # CUDA calcul of the matrix multiplication
